package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.AuthFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Admin;
import com.bwie.common.domain.request.AdminReq;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import com.sun.javafx.css.parser.LadderConverter;
import lombok.AllArgsConstructor;
import org.apache.kafka.clients.admin.AdminClient;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @Author：yang
 * @Package：com.bwie.auth.service.impl
 * @Project：day_09-12
 * @name：AuthServiceImpl
 * @Date：2024/8/12 9:53
 */
@Service
@AllArgsConstructor
public class AuthServiceImpl implements AuthService {


    private final AuthFeign authFeign;
    private final StringRedisTemplate redisTemplate;
    private final HttpServletRequest request;
    private final RabbitTemplate rabbitTemplate;
    /**
     * 登录
     * @param admin 登录对象
     * @return 试图
     */
    @Override
    public Result<AdminReq> user(Admin admin) {

        if (StringUtils.isNull(admin.getAdminName())){
            return Result.error("用户名不可为空");
        }

        Result<Admin> user = authFeign.user(admin.getAdminName());
        Admin data = user.getData();
        if (StringUtils.isNull(data)){
            return Result.error("用户不存在");
        }

        HashMap<String, Object> map = new HashMap<>();
        String s = UUID.randomUUID().toString().replaceAll("-", "");
        map.put(JwtConstants.USER_KEY,s);

        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+s, JSON.toJSONString(data),30, TimeUnit.MINUTES);
        AdminReq adminReq = new AdminReq();
        adminReq.setToken(token);
        return Result.success(adminReq,"登录成功");
    }

    @Override
    public Admin info() {
        String token = request.getHeader(JwtConstants.USER_KEY);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + token);
        Admin admin = JSON.parseObject(s, Admin.class);
        return admin;
    }
}
