package com.bwie.list.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Admin;
import com.bwie.common.domain.Rutcloue;
import com.bwie.common.result.Result;
import com.bwie.common.utils.StringUtils;
import com.bwie.list.mapper.AdminMapper;
import com.bwie.list.service.AdminService;
import lombok.AllArgsConstructor;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.UUID;

/**
 * @Author：yang
 * @Package：com.bwie.list.service.impl
 * @Project：day_09-12
 * @name：AdminServiceImpl
 * @Date：2024/8/12 10:09
 */
@Service
@AllArgsConstructor
public class AdminServiceImpl implements AdminService {

    private final AdminMapper adminMapper;
    private final HttpServletRequest request;
    private final StringRedisTemplate redisTemplate;
    private final RabbitTemplate rabbitTemplate;

    /**
     * 获取登录
     * @param adminName 用户名称
     * @return 值
     */
    @Override
    public Admin user(String adminName) {

        return adminMapper.user(adminName);
    }

    /**
     * 新用户注册
     * @param admin 用户名称
     * @return 值
     */
    @Override
    public Integer restKeran(Admin admin) {
        if (StringUtils.isNull(admin.getAdminName())){return 0;}
        Admin user = this.user(admin.getAdminName());
        if (user!=null){return 2;}
            rabbitTemplate.convertAndSend("yss",JSON.toJSONString(admin),message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
        return adminMapper.restKeran(admin);
    }

    /**
     * 支付
     * @param rutcloue 商品信息
     * @return 值
     */
    @Override
    public Integer rnFerat(Rutcloue rutcloue) {

        String token = request.getHeader(JwtConstants.USER_KEY);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + token);
        Admin admin = JSON.parseObject(s, Admin.class);
        Integer add = adminMapper.rnFerat(admin.getAdminId(),rutcloue.getRutclouePrivce());
        return add>0?adminMapper.upd(rutcloue.getRutcloueId()):0;
    }
}
