package com.bwie.es.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.domain.DTo.KoodDTO;
import com.bwie.common.domain.Kood;
import com.bwie.common.domain.Rutcloue;
import com.bwie.es.service.ESService;
import lombok.AllArgsConstructor;
import org.elasticsearch.action.bulk.BulkRequest;
import org.elasticsearch.action.delete.DeleteRequest;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.common.xcontent.XContentType;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.SearchHits;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author：yang
 * @Package：com.bwie.es.service.impl
 * @Project：day_09-12
 * @name：ESServiceImpl
 * @Date：2024/8/12 13:36
 */
@Service
@AllArgsConstructor
public class ESServiceImpl implements ESService {

    private final RestHighLevelClient client;


    @Override
    public void add(List<Kood> koods) {
        try {
        BulkRequest bulkRequest = new BulkRequest();
        koods.forEach(kood -> {
            bulkRequest.add(new IndexRequest("boods")
                    .id(String.valueOf(kood.getKoodId()))
                    .source(JSONObject.toJSONString(kood),XContentType.JSON));
        });

            client.bulk(bulkRequest, RequestOptions.DEFAULT);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public List<KoodDTO> list(KoodDTO koodDTO) {
        ArrayList<KoodDTO> list = new ArrayList<>();
        try {

            SearchRequest searchRequest = new SearchRequest("boods");
            SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
            BoolQueryBuilder boolQueryBuilder = QueryBuilders.boolQuery();

            if (koodDTO.getKoodName()!=null){
                boolQueryBuilder.must(QueryBuilders.matchQuery(koodDTO.getKoodName(),"koodName"));
            }
            if (koodDTO.getKoodId()!=null){
                boolQueryBuilder.must(QueryBuilders.termQuery(String.valueOf(koodDTO.getKoodId()),"koodId"));
            }

            searchSourceBuilder.query(boolQueryBuilder);
            SearchRequest source = searchRequest.source(searchSourceBuilder);

            SearchResponse search = client.search(searchRequest, RequestOptions.DEFAULT);
            SearchHits hits = search.getHits();
            SearchHit[] hits1 = hits.getHits();
            for (SearchHit documentFields : hits1) {
                String sourceAsString = documentFields.getSourceAsString();
                if (sourceAsString!=null) {
                    KoodDTO koodDTO1 = JSONObject.parseObject(sourceAsString, KoodDTO.class);
                    list.add(koodDTO1);
                }
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
//        list.stream().map(KoodDTO::list).collect(Collectors.toList());
        return list;
    }

    /**
     * 商品列表
     *
     * @param rutcloue 商品实体类
     * @return 返回试图
     */
    @Override
    public List<Rutcloue> rutcloueList(Rutcloue rutcloue) {
        ArrayList<Rutcloue> list = new ArrayList<>();
        try {

            SearchRequest searchRequest = new SearchRequest("boods");
            SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
            BoolQueryBuilder boolQueryBuilder = QueryBuilders.boolQuery();

            if (rutcloue.getRutcloueName()!=null){
                boolQueryBuilder.must(QueryBuilders.matchQuery(rutcloue.getRutcloueName(),"rutcloueName()"));
            }

            searchSourceBuilder.query(boolQueryBuilder);
            searchRequest.source(searchSourceBuilder);

            SearchResponse search = client.search(searchRequest, RequestOptions.DEFAULT);
            SearchHits hits = search.getHits();
            SearchHit[] hits1 = hits.getHits();
            for (SearchHit documentFields : hits1) {
                String sourceAsString = documentFields.getSourceAsString();
                if (sourceAsString!=null) {
                    Rutcloue rutcloue1 = JSONObject.parseObject(sourceAsString, Rutcloue.class);
                    list.add(rutcloue1);
                }
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
//        list.stream().map(KoodDTO::list).collect(Collectors.toList());
        return list;
    }

    @Override
    public void del(String apply) {
        try {
            DeleteRequest deleteRequest = new DeleteRequest(apply);


            client.delete(deleteRequest,RequestOptions.DEFAULT);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
