package com.bwie.list.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.*;
import com.bwie.common.domain.DTo.KoodDTO;
import com.bwie.common.utils.StringUtils;
import com.bwie.list.mapper.KoodMapper;
import com.bwie.list.service.KoodService;
import lombok.AllArgsConstructor;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Author：yang
 * @Package：com.bwie.list.service.impl
 * @Project：day_09-12
 * @name：KoodServiceImpl
 * @Date：2024/8/12 12:00
 */
@Service
@AllArgsConstructor
public class KoodServiceImpl implements KoodService {

    private final KoodMapper koodMapper;
    private final HttpServletRequest request;
    private final StringRedisTemplate redisTemplate;

    @Override
    public List<Kood> list() {
        return koodMapper.list();
    }

    @Transactional
    @Override
    public Integer add(KoodDTO koodDTO) {

        //获取登录人
        String token = request.getHeader(JwtConstants.USER_KEY);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + token);
        Admin admin = JSON.parseObject(s, Admin.class);
        koodDTO.setAdminId(admin.getAdminId());

        Integer add = koodMapper.add(koodDTO);

        //添加中间表
        Zhong zhong = new Zhong();
        zhong.setZhongKoodId(koodDTO.getKoodId());
        zhong.setZhongTypeId(koodDTO.getTypeId());
        koodMapper.addZhong(zhong);
        return add;
    }

    @Override
    public Integer addRes(Rutcloue rutcloue) {

        return koodMapper.addRes(rutcloue);
    }

    @Override
    public String findAdmin(Appyds appyds) {
        String token = request.getHeader(JwtConstants.USER_KEY);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + token);
        Admin admin = JSON.parseObject(s, Admin.class);
        Appyds rutcloueList = koodMapper.findRutcloueList(admin.getAdminId(), appyds);
        if (StringUtils.isNull(rutcloueList)){
            return "商品存在";
        }
        appyds.setAppydsAdminId(admin.getAdminId());
        koodMapper.insertAppyds(appyds);
        if (StringUtils.isNull(admin)){
            return "该登录人已失效";
        }

        return "成功";
    }
}
